==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/MetadataConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class MetadataConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.MetadataConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.MetadataConfigFluent<A>{
  public MetadataConfigFluentImpl() {
  }
  public MetadataConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.MetadataConfig instance) {
    this.withSend(instance.getSend()); 
    this.withSendInterval(instance.getSendInterval()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean send;
  private java.lang.String sendInterval;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getSend() {
    return this.send;
  }
  public A withSend(java.lang.Boolean send) {
    this.send=send; return (A) this;
  }
  public java.lang.Boolean hasSend() {
    return this.send != null;
  }
  public java.lang.String getSendInterval() {
    return this.sendInterval;
  }
  public A withSendInterval(java.lang.String sendInterval) {
    this.sendInterval=sendInterval; return (A) this;
  }
  public java.lang.Boolean hasSendInterval() {
    return this.sendInterval != null;
  }
  
  /**
   * Method is deprecated. use withSendInterval instead.
   */
  @java.lang.Deprecated
  public A withNewSendInterval(java.lang.String arg0) {
    return (A)withSendInterval(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MetadataConfigFluentImpl that = (MetadataConfigFluentImpl) o;
    if (send != null ? !send.equals(that.send) :that.send != null) return false;
    if (sendInterval != null ? !sendInterval.equals(that.sendInterval) :that.sendInterval != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(send,  sendInterval,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/MetadataConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class MetadataConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.MetadataConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.MetadataConfigFluent<A>{
  public MetadataConfigFluentImpl() {
  }
  public MetadataConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.MetadataConfig instance) {
    this.withSend(instance.getSend()); 
    this.withSendInterval(instance.getSendInterval()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean send;
  private java.lang.String sendInterval;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getSend() {
    return this.send;
  }
  public A withSend(java.lang.Boolean send) {
    this.send=send; return (A) this;
  }
  public java.lang.Boolean hasSend() {
    return this.send != null;
  }
  public java.lang.String getSendInterval() {
    return this.sendInterval;
  }
  public A withSendInterval(java.lang.String sendInterval) {
    this.sendInterval=sendInterval; return (A) this;
  }
  public java.lang.Boolean hasSendInterval() {
    return this.sendInterval != null;
  }
  
  /**
   * Method is deprecated. use withSendInterval instead.
   */
  @java.lang.Deprecated
  public A withNewSendInterval(java.lang.String arg0) {
    return (A)withSendInterval(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MetadataConfigFluentImpl that = (MetadataConfigFluentImpl) o;
    if (send != null ? !send.equals(that.send) :that.send != null) return false;
    if (sendInterval != null ? !sendInterval.equals(that.sendInterval) :that.sendInterval != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(send,  sendInterval,  additionalProperties,  super.hashCode());
  }
  
}
